TcpListener

Struct TcpListener 

pub struct TcpListener { /* private fields */ }
An asynchronous TcpListener based on mio library.

Implementations

Source

impl TcpListener

pub fn mio_socket(&self) -> &TcpListener

Returns the immutable reference to the inner mio socket.

pub async fn bind(addr: SocketAddr) -> Result<Self>

Available on crate feature global_reactor only.
pub async fn bind_with(addr: SocketAddr, reactor: Reactor) -> Result<Self>

Convenience method to bind a new TCP listener to the specified address to receive new connections.

pub async fn accept(&self) -> Result<(TcpStream, SocketAddr)>

Accepts a new TcpStream.

If an accepted stream is returned, the remote address of the peer is returned along with it.